@@ -17,7 +17,6 @@ module HTMLProofer
 
       Nokogiri::HTML(clean_content(content))
     end
-    module_function :create_nokogiri
 
     def swap(href, replacement)
       replacement.each do |link, replace|
@@ -25,7 +24,6 @@ module HTMLProofer
       end
       href
     end
-    module_function :swap
 
     # address a problem with Nokogiri's parsing URL entities
     # problem from http://git.io/vBYU1
@@ -35,6 +33,5 @@ module HTMLProofer
         url.gsub(/&(?!amp;)/, '&amp;')
       end
     end
-    module_function :clean_content
   end
 end
